@@ -21,7 +21,8 @@
 #include <string.h>
 #include <stdlib.h>
 
-/* Private data for SKEL file */
+static st_effect_t st_avg_effect;
+
 typedef struct avgstuff {
         /* How to generate each output channel.  sources[i][j] */
         /* represents the fraction of channel i that should be passed */
@@ -45,7 +46,6 @@ typedef struct avgstuff {
 #define MIX_LEFT_BACK   8
 #define MIX_RIGHT_BACK  9
 
-#define ST_AVG_USAGE "usage: avg [ -l | -r | -f | -b | -1 | -2 | -3 | -4 | n,n,n...,n ]"
 
 /*
  * Process options
@@ -83,7 +83,7 @@ int st_avg_getopts(eff_t effp, int n, char **argv)
             avg->mix = MIX_RIGHT_BACK;
         else if (argv[0][0] == '-' && !isdigit((int)argv[0][1])
                 && argv[0][1] != '.') {
-            st_fail(ST_AVG_USAGE);
+            st_fail(st_avg_effect.usage);
             return (ST_EOF);
         }
         else {
@@ -108,7 +108,7 @@ int st_avg_getopts(eff_t effp, int n, char **argv)
         avg->mix = MIX_CENTER;
     }
     else {
-        st_fail(ST_AVG_USAGE);
+        st_fail(st_avg_effect.usage);
         return ST_EOF;
     }
 
@@ -547,3 +547,34 @@ int st_avg_stop(eff_t effp)
     return (ST_SUCCESS); /* nothing to do */
 }
 
+static st_effect_t st_avg_effect = {
+  "avg",
+  "Usage: avg [ -l | -r | -f | -b | -1 | -2 | -3 | -4 | n,n,n...,n ]",
+  ST_EFF_MCHAN | ST_EFF_CHAN,
+  st_avg_getopts,
+  st_avg_start,
+  st_avg_flow,
+  st_effect_nothing_drain,
+  st_avg_stop
+};
+
+static st_effect_t st_pick_effect = {
+  "pick",
+  "Usage: pick [ -l | -r | -f | -b | -1 | -2 | -3 | -4 | n,n,n...,n ]",
+  ST_EFF_MCHAN | ST_EFF_CHAN,
+  st_avg_getopts,
+  st_avg_start,
+  st_avg_flow,
+  st_effect_nothing_drain,
+  st_avg_stop
+};
+
+const st_effect_t *st_avg_effect_fn(void)
+{
+    return &st_avg_effect;
+}
+
+const st_effect_t *st_pick_effect_fn(void)
+{
+    return &st_pick_effect;
+}
