@@ -71,7 +71,8 @@
 #define MOD_TRIANGLE    1
 #define MAX_CHORUS      7
 
-/* Private data for SKEL file */
+static st_effect_t st_chorus_effect;
+
 typedef struct chorusstuff {
         int     num_chorus;
         int     modulation[MAX_CHORUS];
@@ -101,7 +102,7 @@ int st_chorus_getopts(eff_t effp, int n, char **argv)
 
         if ( ( n < 7 ) || (( n - 2 ) % 5 ) )
         {
-            st_fail("Usage: chorus gain-in gain-out delay decay speed depth [ -s | -t ]");
+            st_fail(st_chorus_effect.usage);
             return (ST_EOF);
         }
 
@@ -123,7 +124,7 @@ int st_chorus_getopts(eff_t effp, int n, char **argv)
                         chorus->modulation[chorus->num_chorus] = MOD_TRIANGLE;
                 else
                 {
-                        st_fail("Usage: chorus gain-in gain-out delay decay speed [ -s | -t ]");
+                        st_fail(st_chorus_effect.usage);
                         return (ST_EOF);
                 }
                 i++;
@@ -348,3 +349,19 @@ int st_chorus_stop(eff_t effp)
         }
         return (ST_SUCCESS);
 }
+
+static st_effect_t st_chorus_effect = {
+  "chorus",
+  "Usage: chorus gain-in gain-out delay decay speed depth [ -s | -t ]",
+  0,
+  st_chorus_getopts,
+  st_chorus_start,
+  st_chorus_flow,
+  st_chorus_drain,
+  st_chorus_stop
+};
+
+const st_effect_t *st_chorus_effect_fn(void)
+{
+    return &st_chorus_effect;
+}
