@@ -43,7 +43,8 @@
  * output level of the transfer function.
  */
 
-/* Private data for SKEL file */
+static st_effect_t st_compand_effect;
+
 typedef struct {
   int expectedChannels; /* Also flags that channels aren't to be treated
                            individually when = 1 and input not mono */
@@ -75,13 +76,7 @@ int st_compand_getopts(eff_t effp, int n, char **argv)
 
     if (n < 2 || n > 5)
     {
-      st_fail("Wrong number of arguments for the compander effect\n"
-           "Use: {<attack_time>,<decay_time>}+ {<dB_in>,<db_out>}+ "
-           "[<dB_postamp> [<initial-volume> [<delay_time]]]\n"
-           "where {}+ means `one or more in a comma-separated, "
-           "white-space-free list'\n"
-           "and [] indications possible omission.  dB values are floating\n"
-           "point or `-inf'; times are in seconds.");
+      st_fail (st_compand_effect.usage);
       return (ST_EOF);
     }
     else { /* Right no. of args, but are they well formed? */
@@ -409,3 +404,22 @@ int st_compand_stop(eff_t effp)
 
   return (ST_SUCCESS);
 }
+
+static st_effect_t st_compand_effect = {
+   "compand",
+   "Usage: {<attack_time>,<decay_time>}+ {<dB_in>,<db_out>}+ [<dB_postamp> [<initial-volume> [<delay_time]]]\n"
+   "       where {}+ means e or more in a comma-separated, white-space-free list'\n"
+   "       and [] indications possible omission.  dB values are floating\n"
+   "       point or -inf'; times are in seconds.",
+   ST_EFF_MCHAN,
+   st_compand_getopts,
+   st_compand_start,
+   st_compand_flow,
+   st_compand_drain,
+   st_compand_stop
+};
+
+const st_effect_t *st_compand_effect_fn(void)
+{
+    return &st_compand_effect;
+}
