@@ -59,6 +59,8 @@
 #include <math.h>
 #include "st_i.h"
 
+static st_effect_t st_echo_effect;
+
 #define DELAY_BUFSIZ ( 50L * ST_MAXRATE )
 #define MAX_ECHOS 7     /* 24 bit x ( 1 + MAX_ECHOS ) = */
                         /* 24 bit x 8 = 32 bit !!!      */
@@ -89,7 +91,7 @@ int st_echo_getopts(eff_t effp, int n, char **argv)
 
         if ((n < 4) || (n % 2))
         {
-            st_fail("Usage: echo gain-in gain-out delay decay [ delay decay ... ]");
+            st_fail(st_echo_effect.usage);
             return (ST_EOF);
         }
 
@@ -268,3 +270,19 @@ int st_echo_stop(eff_t effp)
         echo->delay_buf = (double *) -1;   /* guaranteed core dump */
         return (ST_SUCCESS);
 }
+
+static st_effect_t st_echo_effect = {
+  "echo",
+  "Usage: echo gain-in gain-out delay decay [ delay decay ... ]",
+  0,
+  st_echo_getopts,
+  st_echo_start,
+  st_echo_flow,
+  st_echo_drain,
+  st_echo_stop
+};
+
+const st_effect_t *st_echo_effect_fn(void)
+{
+    return &st_echo_effect;
+}
