@@ -57,6 +57,8 @@
 #include <string.h>
 #include "st_i.h"
 
+static st_effect_t st_flanger_effect;
+
 #define MOD_SINE        0
 #define MOD_TRIANGLE    1
 
@@ -85,7 +87,7 @@ int st_flanger_getopts(eff_t effp, int n, char **argv)
 
         if (!((n == 5) || (n == 6)))
         {
-            st_fail("Usage: flanger gain-in gain-out delay decay speed [ -s | -t ]");
+            st_fail(st_flanger_effect.usage);
             return (ST_EOF);
         }
 
@@ -102,7 +104,7 @@ int st_flanger_getopts(eff_t effp, int n, char **argv)
                         flanger->modulation = MOD_TRIANGLE;
                 else
                 {
-                        st_fail("Usage: flanger gain-in gain-out delay decay speed [ -s | -t ]");
+                        st_fail(st_flanger_effect.usage);
                         return (ST_EOF);
                 }
         }
@@ -286,3 +288,19 @@ int st_flanger_stop(eff_t effp)
         flanger->lookup_tab = (int *) -1;   /* guaranteed core dump */
         return (ST_SUCCESS);
 }
+
+static st_effect_t st_flanger_effect = {
+  "flanger",
+  "Usage: flanger gain-in gain-out delay decay speed [ -s | -t ]",
+  0,
+  st_flanger_getopts,
+  st_flanger_start,
+  st_flanger_flow,
+  st_flanger_drain,
+  st_flanger_stop
+};
+
+const st_effect_t *st_flanger_effect_fn(void)
+{
+    return &st_flanger_effect;
+}
