@@ -32,6 +32,8 @@
 #include <math.h>
 #include "st_i.h"
 
+static st_effect_t st_highp_effect;
+
 /* Private data for Highpass effect */
 typedef struct highpstuff {
         float   cutoff;
@@ -48,7 +50,7 @@ int st_highp_getopts(eff_t effp, int n, char **argv)
 
         if ((n < 1) || !sscanf(argv[0], "%f", &highp->cutoff))
         {
-                st_fail("Usage: highp cutoff");
+                st_fail(st_highp_effect.usage);
                 return (ST_EOF);
         }
         return (ST_SUCCESS);
@@ -113,3 +115,18 @@ int st_highp_stop(eff_t effp)
     return (ST_SUCCESS);
 }
 
+static st_effect_t st_highp_effect = {
+  "highp",
+  "Usage: highp cutoff",
+  0,
+  st_highp_getopts,
+  st_highp_start,
+  st_highp_flow,
+  st_effect_nothing_drain,
+  st_highp_stop
+};
+
+const st_effect_t *st_highp_effect_fn(void)
+{
+    return &st_highp_effect;
+}
