@@ -711,3 +711,25 @@ int st_mcompand_stop(eff_t effp)
 
   return (ST_SUCCESS);
 }
+
+static st_effect_t st_mcompand_effect = {
+  "mcompand",
+  "Usage: mcompand quoted_compand_args [crossover_frequency quoted_compand_args [...]]\n"
+  "\n"
+  "quoted_compand_args are as for the compand effect:\n"
+  "\n"
+  "  attack1,decay1[,attack2,decay2...]\n"
+  "                 in-dB1,out-dB1[,in-dB2,out-dB2...]\n"
+  "                [ gain [ initial-volume [ delay ] ] ]\n",
+  ST_EFF_MCHAN,
+  st_mcompand_getopts,
+  st_mcompand_start,
+  st_mcompand_flow,
+  st_mcompand_drain,
+  st_mcompand_stop
+};
+
+const st_effect_t *st_mcompand_effect_fn(void)
+{
+    return &st_mcompand_effect;
+}
