@@ -471,7 +471,7 @@ st_ssize_t st_mp3write(ft_t ft, st_sample_t *buf, st_ssize_t samp)
      goto end;
   }
 
-  done = nsamples;
+  done = nsamples*ft->info.channels;
 
  end:
   free(mp3buffer);
@@ -520,4 +520,29 @@ int st_mp3stopwrite(ft_t ft)
   return ST_EOF;
 }
 #endif /* HAVE_LAME */
+
+/* MP3 */
+static char *mp3names[] = {
+  "mp3",
+  "mp2",
+  NULL,
+};
+
+static st_format_t st_mp3_format = {
+  mp3names,
+  NULL,
+  ST_FILE_STEREO,
+  st_mp3startread,
+  st_mp3read,
+  st_mp3stopread,
+  st_mp3startwrite,
+  st_mp3write,
+  st_mp3stopwrite,
+  st_format_nothing_seek
+};
+
+const st_format_t *st_mp3_format_fn(void)
+{
+    return &st_mp3_format;
+}
 #endif
