@@ -18,6 +18,8 @@
 
 #include "st_i.h"
 
+static st_effect_t st_pan_effect;
+
 /* type for computations.
    float mantissa is okay for 8 or 16 bits signals.
    maybe a little bit short for 24 bits.
@@ -38,10 +40,6 @@
 #define QUARTER  ((PAN_FLOAT)(0.25e0))
 #define ZERO     ((PAN_FLOAT)(0.0e0))
 
-/* error message */
-
-#define PAN_USAGE "Usage: pan direction (in [-1.0 .. 1.0])"
-
 /* structure to hold pan parameter */
 
 typedef struct {
@@ -67,7 +65,7 @@ int st_pan_getopts(eff_t effp, int n, char **argv)
     if (n && (!sscanf(argv[0], PAN_FLOAT_SCAN, &pan->dir) || 
               pan->dir < MONE || pan->dir > ONE))
     {
-        st_fail(PAN_USAGE);
+        st_fail(st_pan_effect.usage);
         return ST_EOF;
     }
 
@@ -448,3 +446,19 @@ int st_pan_stop(eff_t effp)
     }
     return ST_SUCCESS;
 }
+
+static st_effect_t st_pan_effect = {
+  "pan",
+  "Usage: pan direction (in [-1.0 .. 1.0])",
+  ST_EFF_MCHAN | ST_EFF_CHAN,
+  st_pan_getopts,
+  st_pan_start,
+  st_pan_flow,
+  st_effect_nothing_drain,
+  st_pan_stop
+};
+
+const st_effect_t *st_pan_effect_fn(void)
+{
+    return &st_pan_effect;
+}
