@@ -59,6 +59,8 @@
 #include <string.h>
 #include "st_i.h"
 
+static st_effect_t st_phaser_effect;
+
 #define MOD_SINE        0
 #define MOD_TRIANGLE    1
 
@@ -85,7 +87,7 @@ int st_phaser_getopts(eff_t effp, int n, char **argv)
 
         if (!((n == 5) || (n == 6)))
         {
-            st_fail("Usage: phaser gain-in gain-out delay decay speed [ -s | -t ]");
+            st_fail(st_phaser_effect.usage);
             return (ST_EOF);
         }
 
@@ -102,7 +104,7 @@ int st_phaser_getopts(eff_t effp, int n, char **argv)
                         phaser->modulation = MOD_TRIANGLE;
                 else
                 {
-                        st_fail("Usage: phaser gain-in gain-out delay decay speed [ -s | -t ]");
+                        st_fail(st_phaser_effect.usage);
                         return (ST_EOF);
                 }
         }
@@ -277,3 +279,18 @@ int st_phaser_stop(eff_t effp)
         return (ST_SUCCESS);
 }
 
+static st_effect_t st_phaser_effect = {
+  "phaser",
+  "Usage: phaser gain-in gain-out delay decay speed [ -s | -t ]",
+  0,
+  st_phaser_getopts,
+  st_phaser_start,
+  st_phaser_flow,
+  st_phaser_drain,
+  st_phaser_stop
+};
+
+const st_effect_t *st_phaser_effect_fn(void)
+{
+    return &st_phaser_effect;
+}
