@@ -42,6 +42,8 @@
 
 #include <math.h>   /* cos(), pow() */
 
+static st_effect_t st_pitch_effect;
+
 #ifndef MIN
 #define MIN(a,b) (((a)<(b))?(a):(b))
 #endif
@@ -55,11 +57,6 @@
 #define PITCH_FLOAT_SCAN "%lf"
 #endif
 
-#define PITCH_USAGE \
-    "Usage: pitch shift width interpole fade" \
-    " (in cents, in ms, cub/lin, cos/ham/lin/trap)" \
-    " (defaults: 0 20 c c)"
-
 /* cross fading options for transitions
  */
 #define PITCH_FADE_COS 0 /* cosine */
@@ -287,7 +284,7 @@ int st_pitch_getopts(eff_t effp, int n, char **argv)
 
     if (n && !sscanf(argv[0], PITCH_FLOAT_SCAN, &pitch->shift))
     {
-        st_fail(PITCH_USAGE);
+        st_fail(st_pitch_effect.usage);
         return ST_EOF;
     }
 
@@ -295,7 +292,7 @@ int st_pitch_getopts(eff_t effp, int n, char **argv)
     pitch->width = PITCH_DEFAULT_WIDTH;
     if (n>1 && !sscanf(argv[1], PITCH_FLOAT_SCAN, &pitch->width))
     {
-        st_fail(PITCH_USAGE);
+        st_fail(st_pitch_effect.usage);
         return ST_EOF;
     }
 
@@ -314,7 +311,7 @@ int st_pitch_getopts(eff_t effp, int n, char **argv)
             pitch->interopt = PITCH_INTERPOLE_CUB;
             break;
         default:
-            st_fail(PITCH_USAGE);
+            st_fail(st_pitch_effect.usage);
             return ST_EOF;
         }
     }
@@ -342,7 +339,7 @@ int st_pitch_getopts(eff_t effp, int n, char **argv)
             pitch->fadeopt = PITCH_FADE_COS;
             break;
         default:
-            st_fail(PITCH_USAGE);
+            st_fail(st_pitch_effect.usage);
             return ST_EOF;
         }
     }
@@ -351,7 +348,7 @@ int st_pitch_getopts(eff_t effp, int n, char **argv)
     if (n>4 && (!sscanf(argv[4], PITCH_FLOAT_SCAN, &pitch->coef) ||
                 pitch->coef<ZERO || pitch->coef>HALF))
     {
-        st_fail(PITCH_USAGE);
+        st_fail(st_pitch_effect.usage);
         return ST_EOF;
     }
 
@@ -617,3 +614,21 @@ int st_pitch_stop(eff_t effp)
 
     return ST_SUCCESS;
 }
+
+static st_effect_t st_pitch_effect = {
+  "pitch",
+  "Usage: pitch shift width interpole fade\n"
+  "       (in cents, in ms, cub/lin, cos/ham/lin/trap)"
+  "       (defaults: 0 20 c c)",
+  0,
+  st_pitch_getopts,
+  st_pitch_start,
+  st_pitch_flow,
+  st_pitch_drain,
+  st_pitch_stop
+};
+
+const st_effect_t *st_pitch_effect_fn(void)
+{
+    return &st_pitch_effect;
+}
