@@ -664,3 +664,26 @@ int st_poly_stop(eff_t effp)
     }
     return (ST_SUCCESS);
 }
+
+static st_effect_t st_polyphase_effect = {
+  "polyphase",
+  "Usage: -w <nut / ham>        :  window type\n"
+  "       -width <short / long> :  window width\n"
+  "                                short = 128 samples\n"
+  "                                long  = 1024 samples\n"
+  "       <num>                    num:  explicit number\n"
+  "\n"
+  "       -cutoff <float>       :  frequency cutoff for base bandwidth.\n"
+  "                                Default = 0.95 = 95%",
+  ST_EFF_RATE,
+  st_poly_getopts,
+  st_poly_start,
+  st_poly_flow,
+  st_poly_drain,
+  st_poly_stop
+};
+
+const st_effect_t *st_polyphase_effect_fn(void)
+{
+    return &st_polyphase_effect;
+}
