@@ -821,3 +821,238 @@ void rawdefaults(ft_t ft)
         if (ft->info.channels == -1)
                 ft->info.channels = 1;
 }
+
+static char *rawnames[] = {
+  "raw",
+  NULL
+};
+
+static st_format_t st_raw_format = {
+   rawnames,
+   NULL,
+   ST_FILE_STEREO | ST_FILE_SEEK,
+   st_rawstartread,
+   st_rawread,
+   st_rawstopread,
+   st_rawstartwrite,
+   st_rawwrite,
+   st_rawstopwrite,
+   st_rawseek
+};
+
+const st_format_t *st_raw_format_fn(void)
+{
+    return &st_raw_format;
+}
+
+/* a-law byte raw */
+static char *alnames[] = {
+  "al",
+  NULL
+};
+
+static st_format_t st_al_format = {
+  alnames,
+  NULL,
+  ST_FILE_STEREO,
+  st_alstartread,
+  st_rawread,
+  st_rawstopread,
+  st_alstartwrite,
+  st_rawwrite,
+  st_rawstopwrite,
+  st_format_nothing_seek
+};
+
+const st_format_t *st_al_format_fn(void)
+{
+    return &st_al_format;
+}
+
+/* inverse a-law byte raw */
+static char *lanames[] = {
+  "la",
+  NULL
+};
+
+static st_format_t st_la_format = {
+  lanames,
+  NULL,
+  ST_FILE_STEREO,
+  st_lastartread,
+  st_rawread,
+  st_rawstopread,
+  st_lastartwrite,
+  st_rawwrite,
+  st_rawstopwrite,
+  st_format_nothing_seek
+};
+
+const st_format_t *st_la_format_fn(void)
+{
+    return &st_la_format;
+}
+
+/* inverse u-law byte raw */
+static char *lunames[] = {
+  "lu",
+  NULL
+};
+
+static st_format_t st_lu_format = {
+  lunames,
+  NULL,
+  ST_FILE_STEREO,
+  st_lustartread,
+  st_rawread,
+  st_rawstopread,
+  st_lustartwrite,
+  st_rawwrite,
+  st_rawstopwrite,
+  st_format_nothing_seek
+};
+
+const st_format_t *st_lu_format_fn(void)
+{
+    return &st_lu_format;
+}
+
+static char *sbnames[] = {
+  "sb",
+  NULL
+};
+
+static st_format_t st_sb_format = {
+  sbnames,
+  NULL,
+  ST_FILE_STEREO,
+  st_sbstartread,
+  st_rawread,
+  st_rawstopread,
+  st_sbstartwrite,
+  st_rawwrite,
+  st_rawstopwrite,
+  st_format_nothing_seek
+};
+
+const st_format_t *st_sb_format_fn(void)
+{
+    return &st_sb_format;
+}
+
+static char *slnames[] = {
+  "sl",
+  NULL,
+};
+
+static st_format_t st_sl_format = {
+  slnames,
+  NULL,
+  ST_FILE_STEREO,
+  st_slstartread,
+  st_rawread,
+  st_rawstopread,
+  st_slstartwrite,
+  st_rawwrite,
+  st_rawstopwrite,
+  st_format_nothing_seek
+};
+
+const st_format_t *st_sl_format_fn(void)
+{
+    return &st_sl_format;
+}
+
+static char *swnames[] = {
+  "sw",
+  NULL
+};
+
+static st_format_t st_sw_format = {
+  swnames,
+  NULL,
+  ST_FILE_STEREO,
+  st_swstartread,
+  st_rawread,
+  st_rawstopread,
+  st_swstartwrite,
+  st_rawwrite,
+  st_rawstopwrite,
+  st_format_nothing_seek
+};
+
+const st_format_t *st_sw_format_fn(void)
+{
+    return &st_sw_format;
+}
+
+static char *ubnames[] = {
+  "ub",
+  "sou",
+  "fssd",
+  NULL
+};
+
+static st_format_t st_ub_format = {
+  ubnames,
+  NULL,
+  ST_FILE_STEREO,
+  st_ubstartread,
+  st_rawread,
+  st_rawstopread,
+  st_ubstartwrite,
+  st_rawwrite,
+  st_rawstopwrite,
+  st_format_nothing_seek
+};
+
+const st_format_t *st_ub_format_fn(void)
+{
+    return &st_ub_format;
+}
+
+static char *ulnames[] = {
+  "ul",
+  NULL
+};
+
+static st_format_t st_ul_format = {
+   ulnames,
+   NULL,
+   ST_FILE_STEREO,
+   st_ulstartread,
+   st_rawread,
+   st_rawstopread,
+   st_ulstartwrite,
+   st_rawwrite,
+   st_rawstopwrite,
+   st_format_nothing_seek
+};
+
+const st_format_t *st_ul_format_fn(void)
+{
+    return &st_ul_format;
+}
+
+static char *uwnames[] = {
+  "uw",
+  NULL
+};
+
+static st_format_t st_uw_format = {
+  uwnames,
+  NULL,
+  ST_FILE_STEREO,
+  st_uwstartread,
+  st_rawread,
+  st_rawstopread,
+  st_uwstartwrite,
+  st_rawwrite,
+  st_rawstopwrite,
+  st_format_nothing_seek
+};
+
+const st_format_t *st_uw_format_fn(void)
+{
+    return &st_uw_format;
+}
