@@ -24,6 +24,8 @@
 #include <string.h>
 #include "st_i.h"
 
+static st_effect_t st_repeat_effect;
+
 typedef struct repeatstuff {
         FILE *fp;
         int first_drain;
@@ -37,7 +39,7 @@ int st_repeat_getopts(eff_t effp, int n, char **argv)
         repeat_t repeat = (repeat_t)effp->priv;
 
         if (n != 1) {
-                st_fail("Usage: repeat count]");
+                st_fail(st_repeat_effect.usage);
                 return (ST_EOF);
         }
 
@@ -195,3 +197,18 @@ int st_repeat_stop(eff_t effp)
         return (ST_SUCCESS);
 }
 
+static st_effect_t st_repeat_effect = {
+  "repeat",
+  "Usage: repeat count",
+  0,
+  st_repeat_getopts,
+  st_repeat_start,
+  st_repeat_flow,
+  st_repeat_drain,
+  st_repeat_stop
+};
+
+const st_effect_t *st_repeat_effect_fn(void)
+{
+    return &st_repeat_effect;
+}
