@@ -58,6 +58,8 @@
 /* resample includes */
 #include "resampl.h"
 
+static st_effect_t st_resample_effect;
+
 /* this Float MUST match that in filter.c */
 #define Float double/*float*/
 #define ISCALE 0x10000
@@ -145,7 +147,7 @@ int st_resample_getopts(eff_t effp, int n, char **argv)
 
         if ((n >= 1) && (sscanf(argv[0], "%lf", &r->rolloff) != 1))
         {
-          st_fail("Usage: resample [ rolloff [ beta ] ]");
+          st_fail(st_resample_effect.usage);
           return (ST_EOF);
         }
         else if ((r->rolloff <= 0.01) || (r->rolloff >= 1.0))
@@ -156,7 +158,7 @@ int st_resample_getopts(eff_t effp, int n, char **argv)
 
         if ((n >= 2) && !sscanf(argv[1], "%lf", &r->beta))
         {
-          st_fail("Usage: resample [ rolloff [ beta ] ]");
+          st_fail(st_resample_effect.usage);
           return (ST_EOF);
         }
         else if (r->beta <= 2.0) {
@@ -709,3 +711,19 @@ static void LpFilter(double *c, long N, double frq, double Beta, long Num)
       }
    }
 }
+
+static st_effect_t st_resample_effect = {
+   "resample",
+   "Usage: resample [ rolloff [ beta ] ]",
+   ST_EFF_RATE,
+   st_resample_getopts,
+   st_resample_start,
+   st_resample_flow,
+   st_resample_drain,
+   st_resample_stop
+};
+
+const st_effect_t *st_resample_effect_fn(void)
+{
+    return &st_resample_effect;
+}
