@@ -95,6 +95,8 @@
 #include <math.h>
 #include "st_i.h"
 
+static st_effect_t st_reverb_effect;
+
 #define REVERB_FADE_THRESH 10
 #define DELAY_BUFSIZ ( 50L * ST_MAXRATE )
 #define MAXREVERBS 8
@@ -123,7 +125,7 @@ int st_reverb_getopts(eff_t effp, int n, char **argv)
 
         if ( n < 3 )
         {
-            st_fail("Usage: reverb gain-out reverb-time delay [ delay ... ]");
+            st_fail(st_reverb_effect.usage);
             return (ST_EOF);
         }
 
@@ -286,3 +288,19 @@ int st_reverb_stop(eff_t effp)
         reverb->reverbbuf = (float *) -1;   /* guaranteed core dump */
         return (ST_SUCCESS);
 }
+
+static st_effect_t st_reverb_effect = {
+  "reverb",
+  "Usage: reverb gain-out reverb-time delay [ delay ... ]",
+  0,
+  st_reverb_getopts,
+  st_reverb_start,
+  st_reverb_flow,
+  st_reverb_drain,
+  st_reverb_stop
+};
+
+const st_effect_t *st_reverb_effect_fn(void)
+{
+    return &st_reverb_effect;
+}
