@@ -20,6 +20,8 @@
 
 #include "st_i.h"
 
+static st_effect_t st_reverse_effect;
+
 /* Private data */
 typedef struct reversestuff {
         FILE *fp;
@@ -38,7 +40,7 @@ int st_reverse_getopts(eff_t effp, int n, char **argv)
 {
         if (n)
         {
-                st_fail("Reverse effect takes no options.");
+                st_fail(st_reverse_effect.usage);
                 return (ST_EOF);
         }
         return(ST_SUCCESS);
@@ -142,3 +144,19 @@ int st_reverse_stop(eff_t effp)
         fclose(reverse->fp);
         return (ST_SUCCESS);
 }
+
+static st_effect_t st_reverse_effect = {
+  "reverse",
+  "Usage: Reverse effect takes no options",
+  0,
+  st_reverse_getopts,
+  st_reverse_start,
+  st_reverse_flow,
+  st_reverse_drain,
+  st_reverse_stop
+};
+
+const st_effect_t *st_reverse_effect_fn(void)
+{
+    return &st_reverse_effect;
+}
