@@ -256,3 +256,26 @@ static void sndtwriteheader(ft_t ft, st_size_t nsamples)
     st_writebuf(ft, name_buf, 1, 96);
 }
 
+/* Sndtool Sound File */
+static char *sndtnames[] = {
+  "sndt",
+  NULL
+};
+
+const st_format_t st_snd_format = {
+  sndtnames,
+  NULL,
+  ST_FILE_STEREO | ST_FILE_SEEK,
+  st_sndtstartread,
+  st_rawread,
+  st_rawstopread,
+  st_sndtstartwrite,
+  st_sndtwrite,
+  st_sndtstopwrite,
+  st_sndseek
+};
+
+const st_format_t *st_snd_format_fn(void)
+{
+    return &st_snd_format;
+}
