@@ -38,14 +38,10 @@
 #include <unistd.h>             /* for unlink() */
 #endif
 
-#ifdef HAVE_GETOPT_H
+#ifdef HAVE_GETOPT_LONG
 #include <getopt.h>
 #else
-#ifndef HAVE_GETOPT
-int getopt(int,char **,char *);
-extern char *optarg;
-extern int optind;
-#endif
+#include "getopt.h"
 #endif
 
 #include <sys/types.h> /* for fstat() */
@@ -99,6 +95,7 @@ typedef struct file_options
 /* local forward declarations */
 static void doopts(file_options_t *fo, int, char **);
 static void usage(char *) NORET;
+static void usage_effect(char *) NORET;
 static void process(void);
 static void print_input_status(int input);
 static void update_status(void);
@@ -177,6 +174,7 @@ int main(int argc, char **argv)
         if (file_count >= MAX_FILES)
         {
             st_fail("to many filenames. max of %d input files and 1 output files\n", MAX_INPUT_FILES);
+            exit(1);
         }
 
         /*
@@ -251,7 +249,6 @@ int main(int argc, char **argv)
             /* st_open_read() will call st_warn for most errors.
              * Rely on that printing something.
              */
-            cleanup();
             exit(2);
         }
     }
@@ -279,19 +276,39 @@ int main(int argc, char **argv)
     return(0);
 }
 
-#ifdef HAVE_GETOPT_H
 static char *getoptstr = "+r:v:t:c:phsuUAaigbwlfdxVSq";
-#else
-static char *getoptstr = "r:v:t:c:phsuUAaigbwlfdxVSq";
-#endif
+
+static struct option long_options[] =
+{
+    {"version", 0, NULL, 0},
+    {"help", 0, NULL, 'h'},
+    {"help-effect", 1, NULL, 0},
+    {NULL, 0, NULL, 0}
+};
 
 static void doopts(file_options_t *fo, int argc, char **argv)
 {
     int c, i;
+    int option_index;
     char *str;
 
-    while ((c = getopt(argc, argv, getoptstr)) != -1) {
+    while ((c = getopt_long(argc, argv, getoptstr, 
+                            long_options, &option_index)) != -1) {
         switch(c) {
+            case 0:
+                if (strncmp("help-effect", long_options[option_index].name,
+                            11) == 0)
+                    usage_effect(optarg);
+                else if (strncmp("version", long_options[option_index].name,
+                            7) == 0)
+                {
+                    printf("%s: ", myname);
+                    printf("v%s\n", st_version());
+                    exit(0);
+                }
+                /* no return from above */
+                break;
+
             case 'p':
                 soxpreview++;
                 break;
@@ -299,6 +316,7 @@ static void doopts(file_options_t *fo, int argc, char **argv)
             case 'h':
                 usage((char *)0);
                 /* no return from above */
+                break;
 
             case 't':
                 fo->filetype = optarg;
@@ -310,13 +328,21 @@ static void doopts(file_options_t *fo, int argc, char **argv)
                 str = optarg;
                 if ((!sscanf(optarg, "%u", &fo->info.rate)) ||
                     (fo->info.rate <= 0))
+                {
                     st_fail("-r must be given a positive integer");
+                    cleanup();
+                    exit(1);
+                }
                 break;
             case 'v':
                 str = optarg;
                 if (!sscanf(str, "%lf", &fo->volume))
+                {
                     st_fail("Volume value '%s' is not a number",
                             optarg);
+                    cleanup();
+                    exit(1);
+                }
                 fo->uservolume = 1;
                 if (fo->volume < 0.0)
                     st_report("Volume adjustment is negative.  This will result in a phase change\n");
@@ -325,14 +351,22 @@ static void doopts(file_options_t *fo, int argc, char **argv)
             case 'c':
                 str = optarg;
                 if (!sscanf(str, "%d", &i))
+                {
                     st_fail("-c must be given a number");
+                    cleanup();
+                    exit(1);
+                }
                 /* Since we use -1 as a special internal value,
                  * we must do some extra logic so user doesn't
                  * get confused when we translate -1 to mean
                  * something valid.
                  */
                 if (i < 1)
+                {
                     st_fail("-c must be given a positive number");
+                    cleanup();
+                    exit(1);
+                }
                 fo->info.channels = i;
                 break;
             case 'b':
@@ -393,6 +427,11 @@ static void doopts(file_options_t *fo, int argc, char **argv)
                 status = 0;
                 quiet = 1;
                 break;
+
+            case '?':
+                usage((char *)0);
+                /* no return from above */
+                break;
         }
     }
 }
@@ -474,6 +513,7 @@ static void process(void) {
         if (compare_input(file_desc[0], file_desc[f]) != ST_SUCCESS)
         {
             st_fail("Input files must have the same rate, channels, data size, and encoding");
+            exit(1);
         }
     }
 
@@ -575,6 +615,8 @@ static void process(void) {
         if (!ibuf[f])
         {
             st_fail("could not allocate memory");
+            cleanup();
+            exit(1);
         }
 
         if (status)
@@ -615,12 +657,14 @@ static void process(void) {
             ilen = 0;
         }
 
-        /* FIXME: libst needs the feof() and ferror() concepts
-         * to see if ST_EOF means a real failure.  Until then we
-         * must treat ST_EOF as just hiting the end of the file.
-         */
         if (ilen == ST_EOF)
+        {
             efftab[0].olen = 0;
+            if (file_desc[current_input]->st_errno)
+            {
+                fprintf(stderr, file_desc[current_input]->st_errstr);
+            }
+        }
         else
             efftab[0].olen = ilen;
 
@@ -657,12 +701,14 @@ static void process(void) {
         {
             ilen[f] = st_read(file_desc[f], ibuf[f], (st_ssize_t)ST_BUFSIZ);
 
-            /* FIXME: libst needs the feof() and ferror() concepts
-             * to see if ST_EOF means a real failure.  Until then we
-             * must treat ST_EOF as just hiting the end of the buffer.
-             */
             if (ilen[f] == ST_EOF)
+            {
                 ilen[f] = 0;
+                if (file_desc[f]->st_errno)
+                {
+                    fprintf(stderr, file_desc[f]->st_errstr);
+                }
+            }
 
             /* Only count read samples for first file in mix */
             if (f == 0)
@@ -742,7 +788,9 @@ static void process(void) {
     } while (1); 
 
     /* This will drain the effects */
-    drain_effect_out();
+    /* Don't write if output is indicating errors. */
+    if (writing && file_desc[file_count-1]->st_errno)
+        drain_effect_out();
 
 #ifdef SOXMIX
     /* Free input buffers now that they are not used */
@@ -783,6 +831,7 @@ static void process(void) {
 static void parse_effects(int argc, char **argv)
 {
     int argc_effect;
+    int effect_rc;
 
     nuser_effects = 0;
 
@@ -791,6 +840,8 @@ static void parse_effects(int argc, char **argv)
         if (nuser_effects >= MAX_USER_EFF)
         {
             st_fail("To many effects specified.\n");
+            cleanup();
+            exit(2);
         }
 
         argc_effect = st_geteffect_opt(&user_efftab[nuser_effects],
@@ -798,23 +849,26 @@ static void parse_effects(int argc, char **argv)
 
         if (argc_effect == ST_EOF)
         {
-            int i1;
-            fprintf(stderr, "%s: Known effects: ",myname);
-            for (i1 = 0; st_effects[i1].name; i1++)
-                fprintf(stderr, "%s ", st_effects[i1].name);
-            fprintf(stderr, "\n\n");
             st_fail("Effect '%s' is not known!", argv[optind]);
+            cleanup();
+            exit(2);
         }
 
 
         /* Skip past effect name */
         optind++;
 
-        (*user_efftab[nuser_effects].h->getopts)
+        effect_rc = (*user_efftab[nuser_effects].h->getopts)
             (&user_efftab[nuser_effects],
              argc_effect,
              &argv[optind]);
 
+        if (effect_rc == ST_EOF)
+        {
+            cleanup();
+            exit(2);
+        }
+
         /* Skip past the effect arguments */
         optind += argc_effect;
         nuser_effects++;
@@ -831,6 +885,7 @@ static void check_effects(void)
     int i;
     int needchan = 0, needrate = 0, haschan = 0, hasrate = 0;
     int effects_mask = 0;
+    int status;
 
     if (writing)
     {
@@ -851,7 +906,11 @@ static void check_effects(void)
     }
 
     if (haschan > 1)
+    {
         st_fail("Can not specify multiple effects that modify channel #");
+        cleanup();
+        exit(2);
+    }
     if (hasrate > 1)
         st_report("Can not specify multiple effects that change sample rate");
 
@@ -880,9 +939,14 @@ static void check_effects(void)
         st_geteffect(&efftab[neffects], "avg");
 
         /* give default opts for added effects */
-        /* FIXME: Should look at return code and abort on ST_EOF */
-        (* efftab[neffects].h->getopts)(&efftab[neffects],(int)0,
-                                        (char **)0);
+        status = (* efftab[neffects].h->getopts)(&efftab[neffects],(int)0,
+                                                 (char **)0);
+
+        if (status == ST_EOF)
+        {
+            cleanup();
+            exit(2);
+        }
 
         /* Copy format info to effect table */
         effects_mask = st_updateeffect(&efftab[neffects], 
@@ -905,9 +969,14 @@ static void check_effects(void)
             st_geteffect(&efftab[neffects], "resample");
 
         /* set up & give default opts for added effects */
-        /* FIXME: Should look at return code and abort on ST_EOF */
-        (* efftab[neffects].h->getopts)(&efftab[neffects],(int)0,
-                                        (char **)0);
+        status = (* efftab[neffects].h->getopts)(&efftab[neffects],(int)0,
+                                                 (char **)0);
+
+        if (status == ST_EOF)
+        {
+            cleanup();
+            exit(2);
+        }
 
         /* Copy format info to effect table */
         effects_mask = st_updateeffect(&efftab[neffects], 
@@ -964,9 +1033,14 @@ static void check_effects(void)
             st_geteffect(&efftab[neffects], "resample");
 
         /* set up & give default opts for added effects */
-        /* FIXME: Should look at return code and abort on ST_EOF */
-        (* efftab[neffects].h->getopts)(&efftab[neffects],(int)0,
-                                        (char **)0);
+        status = (* efftab[neffects].h->getopts)(&efftab[neffects],(int)0,
+                                                  (char **)0);
+
+        if (status == ST_EOF)
+        {
+            cleanup();
+            exit(2);
+        }
 
         /* Copy format info to effect table */
         effects_mask = st_updateeffect(&efftab[neffects], 
@@ -994,9 +1068,13 @@ static void check_effects(void)
         st_geteffect(&efftab[neffects], "avg");
 
         /* set up & give default opts for added effects */
-        /* FIXME: Should look at return code and abort on ST_EOF */
-        (* efftab[neffects].h->getopts)(&efftab[neffects],(int)0,
-                                        (char **)0);
+        status = (* efftab[neffects].h->getopts)(&efftab[neffects],(int)0,
+                                                 (char **)0);
+        if (status == ST_EOF)
+        {
+            cleanup();
+            exit(2);
+        }
 
         /* Copy format info to effect table */
         effects_mask = st_updateeffect(&efftab[neffects], 
@@ -1030,6 +1108,8 @@ static void reserve_effect_buf(void)
         if (efftab[e].obuf == NULL)
         {
             st_fail("could not allocate memory");
+            cleanup();
+            exit(2);
         }
         if (efftabR[e].name)
         {
@@ -1038,6 +1118,8 @@ static void reserve_effect_buf(void)
             if (efftabR[e].obuf == NULL)
             {
                 st_fail("could not allocate memory");
+                cleanup();
+                exit(2);
             }
         }
     }
@@ -1104,10 +1186,6 @@ static int flow_effect_out(void)
                                       efftab[neffects-1].olen,
                                       file_opts[file_count-1]->volume);
 
-
-          /* FIXME: Should look at return code and abort
-           * on ST_EOF
-           */
           total = 0;
           do
           {
@@ -1121,7 +1199,7 @@ static int flow_effect_out(void)
                              &efftab[neffects-1].obuf[total],
                              (st_ssize_t)efftab[neffects-1].olen-total);
 
-              if (len < 0)
+              if (len < 0 || file_desc[file_count-1]->file.eof)
               {
                   st_warn("Error writing: %s",
                           file_desc[file_count-1]->st_errstr);
@@ -1230,7 +1308,7 @@ static int flow_effect(int e)
 {
     st_ssize_t i, done, idone, odone, idonel, odonel, idoner, odoner;
     st_sample_t *ibuf, *obuf;
-    int effstatus;
+    int effstatus, effstatusl, effstatusr;
 
     /* Do not attempt to do any more effect processing during
      * user aborts as we may be stuck in an infinit flow loop.
@@ -1274,8 +1352,9 @@ static int flow_effect(int e)
 #endif
 
         done = idone + odone;
-    } else {
-
+    } 
+    else 
+    {
         /* Put stereo data in two seperate buffers and run effect
          * on each of them.
          */
@@ -1296,15 +1375,14 @@ static int flow_effect(int e)
         fprintf(stderr, "pre %s odone1=%d, olen1=%d odone=%d olen=%d\n", efftab[e].name, efftab[e-1].odone, efftab[e-1].olen, efftab[e].odone, efftab[e].olen); 
 #endif
 
-        effstatus = (* efftab[e].h->flow)(&efftab[e],
+        effstatusl = (* efftab[e].h->flow)(&efftab[e],
                                           ibufl, obufl, (st_size_t *)&idonel, 
                                           (st_size_t *)&odonel);
 
         /* right */
         idoner = idone/2;               /* odd-length logic */
         odoner = odone/2;
-        /* FIXME: effstatus of previous operation is lost. */
-        effstatus = (* efftabR[e].h->flow)(&efftabR[e],
+        effstatusr = (* efftabR[e].h->flow)(&efftabR[e],
                                            ibufr, obufr, (st_size_t *)&idoner, 
                                            (st_size_t *)&odoner);
 
@@ -1325,15 +1403,23 @@ static int flow_effect(int e)
         fprintf(stderr, "post %s odone1=%d, olen1=%d odone=%d olen=%d\n", efftab[e].name, efftab[e-1].odone, efftab[e-1].olen, efftab[e].odone, efftab[e].olen);
 #endif
 
-
         done = idonel + idoner + odonel + odoner;
+
+        if (effstatusl)
+            effstatus = effstatusl;
+        else
+            effstatus = effstatusr;
     }
     if (effstatus == ST_EOF)
     {
         return ST_EOF;
     }
     if (done == 0)
+    {
         st_fail("Effect took & gave no samples!");
+        cleanup();
+        exit(2);
+    }
     return ST_SUCCESS;
 }
 
@@ -1554,32 +1640,99 @@ static char *usagestr =
 static void usage(char *opt)
 {
     int i;
+    const st_format_t *f;
+    const st_effect_t *e;
 
-        fprintf(stderr, "%s: ", myname);
-        if (verbose || !opt)
-                fprintf(stderr, "%s\n\n", st_version());
-        fprintf(stderr, "Usage: %s\n\n", usagestr);
-        if (opt)
-                fprintf(stderr, "Failed: %s\n", opt);
-        else {
-            fprintf(stderr,"gopts: -e -h -p -q -S -V\n\n");
-            fprintf(stderr,"fopts: -r rate -c channels -s/-u/-U/-A/-a/-i/-g/-f -b/-w/-l/-d -v volume -x\n\n");
-            fprintf(stderr, "effect: ");
-            for (i = 0; st_effects[i].name != NULL; i++) {
-                fprintf(stderr, "%s ", st_effects[i].name);
-            }
-            fprintf(stderr, "\n\neffopts: depends on effect\n\n");
-            fprintf(stderr, "Supported file formats: ");
-            for (i = 0; st_formats[i].names != NULL; i++) {
-                /* only print the first name */
-                fprintf(stderr, "%s ", st_formats[i].names[0]);
-            }
-            fputc('\n', stderr);
+    printf("%s: ", myname);
+    printf("Version %s\n\n", st_version());
+    if (opt)
+        fprintf(stderr, "Failed: %s\n\n", opt);
+    printf("Usage: %s\n\n", usagestr);
+    printf(
+"Global options (gopts):\n"
+"\n"
+"Global options can be specified anywhere on the command\n"
+"\n"
+"-h              print version number and usage information\n"
+"--help          same as -h\n"
+"--help-efffect=name\n"
+"                print usage of specified effect.  use 'all' to print all\n"
+"-p              run in preview mode and run fast\n"
+"-q              run in quite mode.  Inverse of -S option\n"
+"-S              print status while processing audio data.\n"
+"--version       print version number of SoX and exit\n"
+"-V              verbose mode.  print a description during processing phase\n"
+"\n"
+"Format options (fopts):\n"
+"\n"
+"Format options only need to be supplied on input files that are\n"
+"headerless otherwise they are obtained from the audio data's header.\n"
+"Output files will default to the same format options as the input\n"
+"file unless overriden on the command line.\n"
+"\n"
+"-c channels     number of channels in audio data\n"
+"-e              skip processing of this filename.  useful only\n"
+"                on output filename to prevent writing data.\n"
+"-r rate         sample rate of audio\n"
+"-t filetype     file type of audio\n"
+"-v volume       volume adjustment factor (floating point)\n"
+"-x              invert auto-detected endianess of data\n"
+"-s/-u/-U/-A/    sample encoding.  signed/unsigned/u-law/A-law\n"
+"  -a/-i/-g/-f   ADPCM/IMA_ADPCM/GSM/floating point\n"
+"-b/-w/-l/-d     sample size. byte(8-bits)/word(16-bits)/\n"
+"                long(32-bits)/double long(64-bits)\n"
+"\n");
+
+    printf("Supported file formats: ");
+    for (i = 0; st_format_fns[i]; i++) {
+        f = st_format_fns[i]();
+        if (f && f->names)
+        {
+            /* only print the first name */
+            printf("%s ", f->names[0]);
         }
-        exit(1);
+    }
+
+    printf("\n\nSupported effects: ");
+    for (i = 0; st_effect_fns[i]; i++) {
+        e = st_effect_fns[i]();
+        if (e && e->name)
+        {
+            printf("%s ", e->name);
+        }
+    }
+
+    printf( "\n\neffopts: depends on effect\n\n");
+    exit(1);
 }
 
-/* called from util.c::st_fail() */
+static void usage_effect(char *effect)
+{
+    int i;
+    const st_effect_t *e;
+
+    printf("%s: ", myname);
+    printf("v%s\n\n", st_version());
+
+    printf("Effect usage:\n\n");
+
+
+    for (i = 0; st_effect_fns[i]; i++)
+    {
+        e = st_effect_fns[i]();
+        if (e && e->name &&
+            (!strcmp("all", effect) ||  !strcmp(e->name, effect)))
+        {
+            char *p = strstr(e->usage, "Usage: ");
+            printf("%s\n\n", p ? p + 7 : e->usage);
+        }
+    }
+
+    if (!effect)
+        printf("see --help-effect=effect for effopts ('all' for effopts of all effects)\n\n");
+    exit(1);
+} /* usage_effect */
+ 
 void cleanup(void) 
 {
     int i;
