@@ -19,8 +19,8 @@ extern "C" {
 #include <stdlib.h>
 #include "ststdint.h"
 
-/* Release 12.18.1 of libst */
-#define ST_LIB_VERSION_CODE 0x0c1201
+/* Release 12.18.2 of libst */
+#define ST_LIB_VERSION_CODE 0x0c1202
 #define ST_LIB_VERSION(a,b,c) (((a) << 16) + ((b) << 8) + (c))
 
 typedef int32_t st_sample_t;
@@ -166,6 +166,7 @@ typedef struct st_soundstream *ft_t;
 
 typedef struct st_format {
     char         **names;
+    char         *usage;
     unsigned int flags;
     int          (*startread)(ft_t ft);
     st_ssize_t   (*read)(ft_t ft, st_sample_t *buf, st_ssize_t len);
@@ -192,7 +193,7 @@ struct st_soundstream {
     st_fileinfo_t   file;                 /* File data block */
     int             st_errno;             /* Failure error codes */
     char            st_errstr[256];       /* Extend Failure text */
-    st_format_t     *h;                   /* format struct for this file */
+    const st_format_t *h;                 /* format struct for this file */
     /* The following is a portable trick to align this variable on
      * an 8-byte bounder.  Once this is done, the buffer alloced
      * after it should be align on an 8-byte boundery as well.
@@ -203,8 +204,6 @@ struct st_soundstream {
     char   priv[ST_MAX_FILE_PRIVSIZE]; /* format's private data area */
 };
 
-extern st_format_t st_formats[];
-
 /* file flags field */
 #define ST_FILE_STEREO  1  /* does file format support stereo? */
 #define ST_FILE_LOOPS   2  /* does file format support loops? */
@@ -258,6 +257,7 @@ typedef struct st_effect *eff_t;
 typedef struct
 {
     char    *name;                  /* effect name */
+    char    *usage;
     unsigned int flags;
 
     int (*getopts)(eff_t effp, int argc, char **argv);
@@ -273,7 +273,7 @@ struct st_effect
     char            *name;          /* effect name */
     struct st_signalinfo ininfo;    /* input signal specifications */
     struct st_signalinfo outinfo;   /* output signal specifications */
-    st_effect_t     *h;             /* effects driver */
+    const st_effect_t *h;           /* effects driver */
     st_sample_t     *obuf;          /* output buffer */
     st_size_t       odone, olen;    /* consumed, total length */
     /* The following is a portable trick to align this variable on
@@ -286,8 +286,6 @@ struct st_effect
     char priv[ST_MAX_EFFECT_PRIVSIZE]; /* private area for effect */
 };
 
-extern st_effect_t st_effects[]; /* declared in handlers.c */
-
 extern ft_t st_open_read(const char *path, const st_signalinfo_t *info, 
                          const char *filetype);
 extern ft_t st_open_write(const char *path, const st_signalinfo_t *info,
