@@ -501,3 +501,19 @@ static int FFT(short dir,long m,double *re,double *im)
 
    return ST_SUCCESS;
 }
+
+static st_effect_t st_stat_effect = {
+  "stat",
+  "Usage: [ -s n ] [ -rms ] [ -v ] [ -d ]",
+  ST_EFF_MCHAN | ST_EFF_REPORT,
+  st_stat_getopts,
+  st_stat_start,
+  st_stat_flow,
+  st_stat_drain,
+  st_stat_stop
+};
+
+const st_effect_t *st_stat_effect_fn(void)
+{
+    return &st_stat_effect;
+}
