@@ -13,7 +13,8 @@
 
 #include "st_i.h"
 
-/* Private data for SKEL file */
+static st_effect_t st_swap_effect;
+
 typedef struct swapstuff {
     int         order[4];
     int         def_opts;
@@ -35,7 +36,7 @@ int st_swap_getopts(eff_t effp, int n, char **argv)
         swap->def_opts = 0;
         if (n != 2 && n != 4)
         {
-            st_fail("Usage: swap [1 2 | 1 2 3 4]");
+            st_fail(st_swap_effect.usage);
             return (ST_EOF);
         }
         else if (n == 2)
@@ -196,3 +197,19 @@ int st_swap_stop(eff_t effp)
         /* nothing to do */
     return (ST_SUCCESS);
 }
+
+static st_effect_t st_swap_effect = {
+  "swap",
+  "Usage: swap [1 2 | 1 2 3 4]",
+  ST_EFF_MCHAN,
+  st_swap_getopts,
+  st_swap_start,
+  st_swap_flow,
+  st_swap_drain,
+  st_swap_stop
+};
+
+const st_effect_t *st_swap_effect_fn(void)
+{
+    return &st_swap_effect;
+}
