@@ -14,11 +14,11 @@
 #include "st_i.h"
 #include <string.h>
 
+static st_effect_t st_trim_effect;
+
 /* Time resolutin one millisecond */
 #define TIMERES 1000
 
-#define TRIM_USAGE "Trim usage: trim start [length]"
-
 typedef struct
 {
     /* options here */
@@ -57,7 +57,7 @@ int st_trim_getopts(eff_t effp, int n, char **argv)
             if (st_parsesamples(0, trim->length_str,
                                 &trim->length, 't') != ST_SUCCESS)
             {
-                st_fail(TRIM_USAGE);
+                st_fail(st_trim_effect.usage);
                 return(ST_EOF);
             }
         case 1:
@@ -72,12 +72,12 @@ int st_trim_getopts(eff_t effp, int n, char **argv)
             if (st_parsesamples(0, trim->start_str,
                                 &trim->start, 't') != ST_SUCCESS)
             {
-                st_fail(TRIM_USAGE);
+                st_fail(st_trim_effect.usage);
                 return(ST_EOF);
             }
             break;
         default:
-            st_fail(TRIM_USAGE);
+            st_fail(st_trim_effect.usage);
             return ST_EOF;
             break;
 
@@ -95,7 +95,7 @@ int st_trim_start(eff_t effp)
     if (st_parsesamples(effp->ininfo.rate, trim->start_str,
                         &trim->start, 't') != ST_SUCCESS)
     {
-        st_fail(TRIM_USAGE);
+        st_fail(st_trim_effect.usage);
         return(ST_EOF);
     }
     /* Account for # of channels */
@@ -106,7 +106,7 @@ int st_trim_start(eff_t effp)
         if (st_parsesamples(effp->ininfo.rate, trim->length_str,
                     &trim->length, 't') != ST_SUCCESS)
         {
-            st_fail(TRIM_USAGE);
+            st_fail(st_trim_effect.usage);
             return(ST_EOF);
         }
     }
@@ -218,3 +218,19 @@ void st_trim_clear_start(eff_t effp)
     trim_t trim = (trim_t)effp->priv;
     trim->start = 0;
 }
+
+static st_effect_t st_trim_effect = {
+  "trim",
+  "Usage: trim start [length]",
+  ST_EFF_MCHAN,
+  st_trim_getopts,
+  st_trim_start,
+  st_trim_flow,
+  st_effect_nothing_drain,
+  st_effect_nothing
+};
+
+const st_effect_t *st_trim_effect_fn(void)
+{
+    return &st_trim_effect;
+}
