@@ -60,10 +60,13 @@ void st_warn(const char *fmt, ...)
         fprintf(stderr, "\n");
 }
 
+/* Warning: This function is depricated.  st_fail_errno() is
+ * the preferred way so that applications can control printing
+ * to their choice; not just stderr.
+ */
 void st_fail(const char *fmt, ...)
 {
         va_list args;
-        extern void cleanup();
 
         fprintf(stderr, "%s: ", myname);
 
@@ -71,8 +74,6 @@ void st_fail(const char *fmt, ...)
         vfprintf(stderr, fmt, args);
         va_end(args);
         fprintf(stderr, "\n");
-        cleanup();
-        exit(2);
 }
 
 
@@ -130,30 +131,32 @@ int strcmpcase(char *s1, char *s2)
  */
 int st_gettype(ft_t formp)
 {
-        char **list;
-        int i;
+    char **list;
+    int i;
+    const st_format_t *f;
 
-        if (! formp->filetype){
-            st_fail_errno(formp,
-                          ST_EFMT,
-                          "Filetype was not specified");
-                return(ST_EFMT);
+    if (! formp->filetype){
+        st_fail_errno(formp,
+                      ST_EFMT,
+                      "Filetype was not specified");
+        return(ST_EFMT);
+    }
+    for(i = 0; st_format_fns[i]; i++) {
+        f = st_format_fns[i]();
+        for(list = f->names; *list; list++) {
+            char *s1 = *list, *s2 = formp->filetype;
+            if (! strcmpcase(s1, s2))
+                break;  /* not a match */
         }
-        for(i = 0; st_formats[i].names; i++) {
-                for(list = st_formats[i].names; *list; list++) {
-                        char *s1 = *list, *s2 = formp->filetype;
-                        if (! strcmpcase(s1, s2))
-                                break;  /* not a match */
-                }
-                if (! *list)
-                        continue;
-                /* Found it! */
-                formp->h = &st_formats[i];
-                return ST_SUCCESS;
-        }
-        st_fail_errno(formp, ST_EFMT, "File type '%s' is not known",
-                      formp->filetype);
-        return ST_EFMT;
+        if (! *list)
+            continue;
+        /* Found it! */
+        formp->h = f;
+        return ST_SUCCESS;
+    }
+    st_fail_errno(formp, ST_EFMT, "File type '%s' is not known",
+                  formp->filetype);
+    return ST_EFMT;
 }
 
 /*
@@ -164,47 +167,55 @@ int st_gettype(ft_t formp)
  */
 int st_geteffect_opt(eff_t effp, int argc, char **argv)
 {
-        int i, optind;
+    int i, optind;
 
-        for(i = 0; st_effects[i].name; i++)
+    for(i = 0; st_effect_fns[i]; i++)
+    {
+        char *s1, *s2;
+        const st_effect_t *e = st_effect_fns[i]();
+
+        if (!e || !e->name)
+            continue;
+
+        s1 = e->name;
+        s2 = argv[0];
+
+        while(*s1 && *s2 && (tolower(*s1) == tolower(*s2)))
+            s1++, s2++;
+        if (*s1 || *s2)
+            continue;       /* not a match */
+
+        /* Found it! */
+        effp->name = e->name;
+        effp->h = e;
+
+        optind = 1;
+
+        while (optind < argc)
         {
-            char *s1 = st_effects[i].name, *s2 = argv[0];
-
-            while(*s1 && *s2 && (tolower(*s1) == tolower(*s2)))
-                s1++, s2++;
-            if (*s1 || *s2)
-                continue;       /* not a match */
-
-            /* Found it! */
-            effp->name = st_effects[i].name;
-            effp->h = &st_effects[i];
-
-            optind = 1;
-
-            while (optind < argc)
+            for (i = 0; st_effect_fns[i]; i++)
             {
-                for (i = 0; st_effects[i].name; i++)
-                {
-                    char *s1 = st_effects[i].name, *s2 = argv[optind];
-                    while (*s1 && *s2 && (tolower(*s1) == tolower(*s2)))
+                const st_effect_t *e = st_effect_fns[i]();
+                char *s1 = e->name, *s2 = argv[optind];
+                while (*s1 && *s2 && (tolower(*s1) == tolower(*s2)))
                     s1++, s2++;
-                    if (*s1 || *s2)
-                        continue;
+                if (*s1 || *s2)
+                    continue;
 
-                    /* Found it! */
-                    return (optind - 1);
-                }
-                /* Didn't find a match, try the next argument. */
-                optind++;
+                /* Found it! */
+                return (optind - 1);
             }
-            /*
-             * No matches found, all the following arguments are
-             * for this effect passed in.
-             */
-            return (optind - 1);
+            /* Didn't find a match, try the next argument. */
+            optind++;
         }
+        /*
+         * No matches found, all the following arguments are
+         * for this effect passed in.
+         */
+        return (optind - 1);
+    }
 
-        return (ST_EOF);
+    return (ST_EOF);
 }
 
 /*
@@ -215,47 +226,59 @@ int st_geteffect_opt(eff_t effp, int argc, char **argv)
 
 int st_geteffect(eff_t effp, char *effect_name)
 {
-        int i;
+    int i;
 
-        for(i = 0; st_effects[i].name; i++) {
-                char *s1 = st_effects[i].name, *s2 = effect_name;
+    for(i = 0; st_effect_fns[i]; i++) {
+        char *s1, *s2;
+        const st_effect_t *e = st_effect_fns[i]();
 
-                while(*s1 && *s2 && (tolower(*s1) == tolower(*s2)))
-                        s1++, s2++;
-                if (*s1 || *s2)
-                        continue;       /* not a match */
+        if (!e || !e->name)
+            continue;
 
-                /* Found it! */
-                effp->name = st_effects[i].name;
-                effp->h = &st_effects[i];
+        s1 = e->name;
+        s2 = effect_name;
 
-                return ST_SUCCESS;
-        }
+        while(*s1 && *s2 && (tolower(*s1) == tolower(*s2)))
+            s1++, s2++;
+        if (*s1 || *s2)
+            continue;       /* not a match */
 
-        return (ST_EOF);
+        /* Found it! */
+        effp->name = e->name;
+        effp->h = e;
+
+        return ST_SUCCESS;
+    }
+
+    return (ST_EOF);
 }
 
 /*
  * Check that we have a known effect name.  Return ST_SUCESS if found, else
  * return ST_EOF.
  */
-
 int st_checkeffect(char *effect_name)
 {
-        int i;
+    int i;
 
-        for(i = 0; st_effects[i].name; i++) {
-                char *s1 = st_effects[i].name, *s2 = effect_name;
+    for(i = 0; st_effect_fns[i]; i++) {
+        char *s1, *s2;
+        const st_effect_t *e = st_effect_fns[i]();
 
-                while(*s1 && *s2 && (tolower(*s1) == tolower(*s2)))
-                        s1++, s2++;
-                if (*s1 || *s2)
-                        continue;       /* not a match */
+        if (!e || !e->name)
+            continue;
 
-                return ST_SUCCESS;
-        }
+        s1 = e->name;
+        s2 = effect_name;
+        while(*s1 && *s2 && (tolower(*s1) == tolower(*s2)))
+            s1++, s2++;
+        if (*s1 || *s2)
+            continue;       /* not a match */
 
-        return (ST_EOF);
+        return ST_SUCCESS;
+    }
+
+    return (ST_EOF);
 }
 
 /*
