@@ -72,7 +72,11 @@
 #include "ima_rw.h"
 #include "adpcm.h"
 #ifdef ENABLE_GSM
-#include "gsm/gsm.h"
+#if defined(EXTERNAL_GSM)
+#include <gsm/gsm.h>
+#else
+#include "libgsm/gsm.h"
+#endif
 #endif
 
 #undef PAD_NSAMPS
@@ -1778,3 +1782,27 @@ int st_wavseek(ft_t ft, st_size_t offset)
 
     return(ft->st_errno);
 }
+
+/* Microsoftt RIFF */
+static char *wavnames[] = {
+  "wav",
+  NULL
+};
+
+static st_format_t st_wav_format = {
+  wavnames,
+  NULL,
+  ST_FILE_STEREO | ST_FILE_SEEK,
+  st_wavstartread,
+  st_wavread,
+  st_wavstopread,
+  st_wavstartwrite,
+  st_wavwrite,
+  st_wavstopwrite,
+  st_wavseek
+};
+
+const st_format_t *st_wav_format_fn()
+{
+    return &st_wav_format;
+}
